;;; GNU Guix --- Functional package management for GNU
;;; Copyright © 2020 Mathieu Othacehe <m.othacehe@gmail.com>
;;;
;;; This file is part of GNU Guix.
;;;
;;; GNU Guix is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or (at
;;; your option) any later version.
;;;
;;; GNU Guix is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.

(define-module (nongnu system images pinenote)
  #:use-module (gnu bootloader)
  #:use-module (gnu bootloader u-boot)
  #:use-module (gnu image)
  #:use-module (gnu packages certs)
  #:use-module (gnu packages ssh)
  #:use-module (gnu packages wm)
  #:use-module (nongnu packages linux)
  #:use-module (nongnu packages firmware)
  #:use-module (nongnu packages bootloaders)
  #:use-module (guix platforms arm)
  #:use-module (gnu services)
  #:use-module (gnu services base)
  #:use-module (gnu services desktop)
  #:use-module (gnu services sddm)
  #:use-module (gnu system)
  #:use-module (gnu system file-systems)
  #:use-module (gnu system image)
  #:use-module (srfi srfi-26)
  #:export (pinenote-raw-image
            pinenote-image-type
            pinenote-barebones-raw-image))

(define pinenote-barebone-os
  (operating-system
    (host-name "viso")
    (timezone "Europe/Prague")
    (locale "en_US.utf8")

    (bootloader (bootloader-configuration
                 (bootloader u-boot-pinenote-rk3566-bootloader)
                 (targets '("/dev/vda"))))
    (initrd-modules '())

	(firmware (list pinenote-firmware))
    (kernel linux-pinenote)
    (file-systems (cons* (file-system
                          (device (file-system-label "boot"))
                          (mount-point "/boot/efi")
                          (type "ext4"))
                        (file-system
                          (device (file-system-label "rootfs"))
                          (mount-point "/")
                          (type "ext4"))
                        %base-file-systems))

    (packages (append (list nss-certs
                     openssh
                     sway)
                     %base-packages))

    (services (append (list  ;(service sddm-service-type)
	                 (service agetty-service-type
                             (agetty-configuration
                              (extra-options '("-L")) ; no carrier detect
                              (baud-rate "1500000")
                              (term "vt100")
                              (tty "ttyS2"))))
                    %base-services))))

(define pinenote-image-type
  (image-type
   (name 'pinenote-raw)
   (constructor (cut image-with-os
                     (raw-with-offset-disk-image (* 32 (expt 2 20))) ; 32MiB
                     <>))))

(define pinenote-barebones-raw-image
  (image
   (inherit
    (os+platform->image pinenote-barebone-os aarch64-linux
                        #:type pinenote-image-type))
   (name 'pinenote-barebones-raw-image)))

;; Return the default image.
pinenote-barebones-raw-image
